@@ -128,7 +128,6 @@ class PreseemGrpcClient(object):
     def __init__(self, api_key, host=None, port=None):
         self.api_key = api_key
         self._executor = concurrent.futures.ThreadPoolExecutor(max_workers=10)
-        self._loop = asyncio.get_event_loop()
         self.host = host or 'nmapi.preseem.com'
         self.port = port or 443
         self._channel = None
@@ -189,6 +188,7 @@ class PreseemGrpcClient(object):
         return r
 
     async def _grpc_op(self, op, req, num_retries=5, timeout=None, collect_results=None):
+        loop = asyncio.get_event_loop()
         for retry_num in range(num_retries + 1):
             if retry_num > 0:
                 await asyncio.sleep(2**retry_num)
@@ -197,17 +197,17 @@ class PreseemGrpcClient(object):
                 if timeout:
                     try:
                         if collect_results:
-                            return await asyncio.wait_for(self._loop.run_in_executor(self._executor,  self._grpc_op_collect, op, req), timeout=timeout)
+                            return await asyncio.wait_for(loop.run_in_executor(self._executor,  self._grpc_op_collect, op, req), timeout=timeout)
                         else:
-                            return await asyncio.wait_for(self._loop.run_in_executor(self._executor,  op, req), timeout=timeout)
+                            return await asyncio.wait_for(loop.run_in_executor(self._executor,  op, req), timeout=timeout)
                     except asyncio.TimeoutError:
                         logging.warning('GRPC operation timed out: %s', op)
                         raise
                 else:
                     if collect_results:
-                        x = await self._loop.run_in_executor(self._executor, self._grpc_op_collect, op, req)
+                        x = await loop.run_in_executor(self._executor, self._grpc_op_collect, op, req)
                     else:
-                        x = await self._loop.run_in_executor(self._executor, op, req)
+                        x = await loop.run_in_executor(self._executor, op, req)
                     return x
             except grpc.RpcError as err:
                 logging.debug('Error calling service: %s (%s)', err.code(), err.details())
@@ -265,7 +265,7 @@ class PreseemGrpcClient(object):
 
     async def connect(self):
         """Connect to the server and authenticate."""
-        await self._loop.run_in_executor(self._executor, self._connect)
+        await asyncio.get_event_loop().run_in_executor(self._executor, self._connect)
 
     async def nm_ent_subscribe(self, cbk, company_id=None, resolve=False):
         """Block in this coroutine and call cbk as notifications arrive."""
