@@ -161,7 +161,11 @@ class PreseemNetworkMetadataModel(object):
             self.pt4 = pytricia.PyTricia(32)
             for ip, nm in self.nms.items():
                 if ':' not in ip:
-                    self.pt4[ip] = nm
+                    try:
+                        self.pt4[ip] = nm
+                    except Exception as err:
+                        logging.warning('Error setting nm entity %s: %s', ip, err)
+                        continue
             self.nm_syn = None
             if self._cbk:
                 for nm in self.nms.values():
@@ -183,7 +187,11 @@ class PreseemNetworkMetadataModel(object):
             else:
                 self.nm_syn[nm.network_prefix] = nm
                 if ':' not in msg.entity.network_prefix:
-                    self.pt4[msg.entity.network_prefix] = nm
+                    try:
+                        self.pt4[nm.network_prefix] = nm
+                    except Exception as err:
+                        logging.warning('Error setting nm entity %s: %s', nm.network_prefix, err)
+                        del self.nm_syn[nm.network_prefix]
         elif msg.action == network_metadata_pb2.NetworkMetadataEntityAction.DELETE:
             nm = self._make_nm(msg.entity)
             try:
