@@ -139,6 +139,7 @@ async def sync_preseem_model(preseem_model,
 
         # Create or update elements
         ap_model_refs = nm_model.refs.get('ap_model') or {}
+        num_set = 0
         for ap_ref in aps.values():
             elem = ap_elem.get(ap_ref.value)
             ip = ap_ref.attributes.get('ip_address')
@@ -184,11 +185,11 @@ async def sync_preseem_model(preseem_model,
                 elem_uuid = str(UUID(bytes=elem.uuid))
                 if not model_ref or model_ref.attributes.get(
                         'uuid') != elem_uuid:
-                    await nm_model.set_ref(
-                        NetworkMetadataReference('ap_model', ap_ref.value,
-                                                 {'uuid': elem_uuid}))
-                if throttle:
-                    break  # STM-7295 only do an action per call
+                    if not throttle or num_set == 0:
+                        await nm_model.set_ref(
+                            NetworkMetadataReference('ap_model', ap_ref.value,
+                                                     {'uuid': elem_uuid}))
+                        num_set += 1
 
         # Cleanup elements that were referencing a billing entity but are no longer.
         for elem in model_elems.values():
