@@ -26,8 +26,9 @@ import google.protobuf.timestamp_pb2
 
 import preseem_protobuf.model
 
-async def _op(model, op, reqtype, delete=False, **kwargs):
-    """Wrapper function to perform a GRPC operation on the model."""
+def _py_result(model, r, del_uuid):
+    """Convert the result of a model operation to a python value,
+       and update the object cache in the model."""
     def pb2py(pb, cls):
         """convert a protobuf to a python object."""
         fields = {}
@@ -66,6 +67,26 @@ async def _op(model, op, reqtype, delete=False, **kwargs):
             return curpy
         raise RuntimeError('No UUID found on received object')
 
+    if isinstance(r, list):
+        if r:
+            cls = model._types.get(r[0].DESCRIPTOR.name)
+            return [pb2py(x, cls) for x in r]
+        return []
+    else:
+        cls = model._types.get(r.DESCRIPTOR.name)
+        if cls:
+            return pb2py(r, cls)
+        if del_uuid:
+            # this was a delete operation; delete our cached object data
+            cur = model._objs.pop(del_uuid, None)
+            return cur[1] if cur else None
+        if len(r.DESCRIPTOR.fields) == 0:
+            # This is just an empty response, we simply return None.
+            return
+        return r
+
+def _pb_request(op, reqtype, **kwargs):
+    """Setup a GRPC request protobuf for the given model operation."""
     req = reqtype()
     for k, v in kwargs.items():
         f = reqtype.DESCRIPTOR.fields_by_name[k]
@@ -89,28 +110,26 @@ async def _op(model, op, reqtype, delete=False, **kwargs):
                 assert False  # TODO nested types, we don't need this yet
         else:
             setattr(req, k, v)
+    return req
 
+async def _op(model, op, reqtype, delete=False, **kwargs):
+    """Wrapper function to perform a GRPC operation on the model. (asyncio)"""
+    req = _pb_request(op, reqtype, **kwargs)
     r = await model._client._grpc_op(op, req, collect_results=True)
-    if isinstance(r, list):
-        if r:
-            cls = model._types.get(r[0].DESCRIPTOR.name)
-            return [pb2py(x, cls) for x in r]
-        return []
-    else:
-        cls = model._types.get(r.DESCRIPTOR.name)
-        if cls:
-            return pb2py(r, cls)
-        if delete:
-            # this was a delete operation; delete our cached object data
-            uuid = kwargs.get('uuid')
-            if uuid:
-                cur = model._objs.pop(uuid, None)
-                return cur[1] if cur else None
-        if len(r.DESCRIPTOR.fields) == 0:
-            # This is just an empty response, we simply return None.
-            return
-        return r
+    del_uuid = kwargs.get('uuid') if delete else None
+    return _py_result(model, r, del_uuid)
 
+def _op_sync(model, op, reqtype, delete=False, **kwargs):
+    """Wrapper function to perform a GRPC operation on the model. (non-asyncio)"""
+    req = _pb_request(op, reqtype, **kwargs)
+    r = op(req, **kwargs)
+    try:
+        iterator = iter(r)  # this is to detect whether its a sequence
+        r = [x for x in iterator]  # this does network i/o
+    except TypeError:  # not an iterable result, ok
+        pass
+    del_uuid = kwargs.get('uuid') if delete else None
+    return _py_result(model, r, del_uuid)
 
 # XXX once we require Python 3.7, this should be a dataclass.
 class BaseModelObject:
@@ -145,9 +164,8 @@ class PreseemModel:
         self._objs = {}
         self._types = {}
 
-    async def init(self):
-        """Dynamically load model protobuf modules."""
-        await self._client.connect()
+    def _load(self, wrapper):
+        """Load the model and create Python wrappers for things."""
         pkgpath = os.path.dirname(preseem_protobuf.model.__file__)
         for x in pkgutil.iter_modules([pkgpath]):
             if x.name.endswith('_pb2_grpc'):
@@ -174,8 +192,18 @@ class PreseemModel:
                         reqns = type(reqtype.DESCRIPTOR.name, (BaseModelObject,), {})
                         setattr(cls, reqtype.DESCRIPTOR.name, reqns)
                         op=getattr(svcstub, method.name)
-                        setattr(cls, method.name, partial(_op, model=self, op=op, delete=method.name=='Delete', reqtype=reqtype))
+                        setattr(cls, method.name, partial(wrapper, model=self, op=op, delete=method.name=='Delete', reqtype=reqtype))
                         for nt in reqtype.DESCRIPTOR.nested_types:
                             # Create a nested object class
                             nc = type(nt.name, (BaseModelObject,), {f: None for f in nt.fields_by_name})
                             setattr(reqns, nt.name, nc)
+
+    async def init(self):
+        """Dynamically load model protobuf modules."""
+        await self._client.connect()
+        self._load(_op)
+
+    def load(self):
+        """Dynamically load model protobuf modules. (non-asyncio)"""
+        self._client._connect()
+        self._load(_op_sync)
